import pkg from "../package.json";
import Khipu from "../libkhipu/khipu.js";
import i18n from "./i18n/index.js";
import mutations from "./mutations/index.js";
import queries from "./queries/index.js";
import resolvers from "./resolvers/index.js";
import schemas from "./schemas/index.js";

import reactionPaymentKhipuCapturePayment from "./util/reactionPaymentKhipuCapturePayment.js";
import reactionPaymentKhipuCreateAuthorizedPayment from "./util/reactionPaymentKhipuCreateAuthorizedPayment.js";
import reactionPaymentKhipuCreateRefund from "./util/reactionPaymentKhipuCreateRefund.js";
import reactionPaymentKhipuListRefunds from "./util/reactionPaymentKhipuListRefunds.js";
import startup from "./startup.js";
import config from "./config.js";

/**
 * @summary Import and call this function to add this plugin to your API.
 * @param {ReactionAPI} app The ReactionAPI instance
 * @returns {undefined}
 */
export default async function register(app) {
  const { KHIPU_BASE_PATH: basePath, KHIPU_RECEIVER_ID: receiverID, KHIPU_SECRET: secret } = config;
  const khipuClient = new Khipu({ basePath, receiverID, secret });

  await app.registerPlugin({
    label: "Reaction payment khipu",
    name: "reaction-payment-khipu",
    version: pkg.version,
    i18n,
    collections: {
      ReactionPaymentKhipuRefunds: {
        name: "ReactionPaymentKhipuRefunds",
        indexes: [
          [{ createdAt: 1 }],
          [{ transactionId: 1 }],
          [{ status: 1, shopId: 1 }],
          [{ shopId: 1, createdAt: 1 }]
        ]
      }
    },
    graphQL: {
      resolvers,
      schemas
    },
    mutations,
    queries,
    functionsByType: {
      startup: [startup]
    },
    contextAdditions: {
      khipuClient
    },
    paymentMethods: [{
      name: "payment_khipu",
      canRefund: true,
      displayName: "Reaction Khipu Payment",
      functions: {
        capturePayment: reactionPaymentKhipuCapturePayment,
        createAuthorizedPayment: reactionPaymentKhipuCreateAuthorizedPayment,
        createRefund: reactionPaymentKhipuCreateRefund,
        listRefunds: reactionPaymentKhipuListRefunds
      }
    }]
  });
}
