import Logger from "@reactioncommerce/logger";

/**
 * @name KhipuRefund/resolveOrderFromtransactionId
 * @method
 * @memberof Khipu/GraphQL
 * @summary A generic resolver that gets the order object for the provided parent result, assuming it has a `transactionId` property
 * @param {Object} parent - result of the parent resolver
 * @param {Object} _ - unused
 * @param {Object} context - an object containing the per-request state
 * @returns {Promise<Object>} The order having the transaction with ID parent.transactionId, in GraphQL schema format
 */
export default async function resolveOrderFromtransactionId(parent, _, context) {
  const { collections } = context;
  const { transactionId, shopId } = parent;
  if (!transactionId || !shopId) {
    Logger.error("orderFromTransactionId: Parent must have transactionId and shopId properties");
    return null;
  }

  const order = await collections.Orders.findOne({ payments: { $elemMatch: { processor: "khipu", transactionId } } });
  if (!order) {
    Logger.error("orderFromTransactionId: Order not found");
    return null;
  }

  if (order.shopId != shopId) {
    const filteredGroups = order.shipping.filter((shipping) => shipping.shopId == shopId);

    if (filteredGroups.length > 0) {
      return { ...order, shipping: filteredGroups };
    }
  }

  return order;
}
