import collectionIndex from "@reactioncommerce/api-utils/collectionIndex.js";
import express from "express";

/**
 * @summary Called on startup
 * @param {Object} context Startup context
 * @param {Object} context.collections Map of MongoDB collections
 * @returns {undefined}
 */
export default function khipuPaymentStartup(context) {
  const { app, collections } = context;
  const { Orders } = collections;

  collectionIndex(
    Orders,
    { "payments.transactionId": 1 },
    { unique: true, partialFilterExpression: { "payments.processor": { $eq: "khipu" } } }
  );
  collectionIndex(
    Orders,
    { "payments.status": 1, "payments.data.expiresAfter": 1 },
    { partialFilterExpression: { "payments.processor": { $eq: "khipu" } } }
  );

  if (app.expressApp) {
    app.expressApp.post(
      "/khipu/notification",
      express.json({ limit: 160 }),
      express.urlencoded({ extended: false, limit: 160, parameterLimit: 8 }),
      async (req, res) => {
        const { api_version, notification_token } = req.body;

        if (api_version == "1.3") {
          try {
            await context.mutations.updateKhipuInfo(
              context.getInternalContext(),
              { notificationToken: notification_token }
            );
            res.send("ok");
          } catch (e) {
            console.error("/khipu/notification", e.message);
            res.sendStatus(404);
          }
        } else {
          res.sendStatus(404);
        }
      }
    );
  }
}
