import Random from "@reactioncommerce/random";

import config from "../config.js";

const METHOD = "unknown";
const PACKAGE_NAME = "reaction-payment-khipu";
const PAYMENT_METHOD_NAME = "payment_khipu";

// NOTE: The "processor" value is lowercased and then prefixed to various payment Meteor method names,
// so for example, if this is "Example", the list refunds method is expected to be named "example/refund/list"
const PROCESSOR = "khipu";

/**
 * @summary As an example and for demos, this non-production payment method creates a payment
 *   without charging any credit card
 * @param {Object} context The request context
 * @param {Object} input Input necessary to create a payment
 * @returns {Object} The payment object in schema expected by the orders plugin
 */
export default async function reactionPaymentKhipuCreateAuthorizedPayment(context, input) {
  const { KHIPU_SEND_NOTIFICATION: shouldSendNotification } = config;
  const { khipuClient } = context;
  const {
    amount,
    billingAddress,
    currencyCode,
    email,
    shopId,
    paymentData: {
      fullName,
      referenceId
    }
  } = input;

  const now = new Date();
  const expiresAfter = new Date(now.getTime() + (7 * 24 * 60 * 60000));

  const notificationOptions = shouldSendNotification ? {
    notify_url: context.getAbsoluteUrl("/khipu/notification"),
    notify_api_version: "1.3"
  } : {};
  const { payment_id, payment_url, app_url } = await khipuClient.paymentsPost(
    `Pago por Orden #${referenceId}`,
    currencyCode, Math.round(amount),
    {
      expires_date: expiresAfter.toISOString(),
      payer_name: fullName,
      payer_email: email,
      send_email: true,
      // return_url: ?`URL_BASE_RET? ${orderId}`,
      // cancel_url: ?`URL_BASE_CAN? ${orderId}`,
      transaction_id: referenceId,
      ...notificationOptions
    }
  );

  return {
    _id: Random.id(),
    address: billingAddress,
    amount,
    createdAt: now,
    currencyCode,
    data: {
      webURL: payment_url,
      appURL: app_url,
      expiresAfter,
      gqlType: "ReactionPaymentKhipuData" // GraphQL union resolver uses this
    },
    displayName: `Khipu ${fullName}`,
    method: METHOD,
    mode: "authorize",
    name: PAYMENT_METHOD_NAME,
    paymentPluginName: PACKAGE_NAME,
    processor: PROCESSOR,
    riskLevel: "normal",
    shopId,
    status: "created",
    transactionId: payment_id,
    transactions: []
  };
}
