/* eslint camelcase: 0 */
import nock from "nock";
import mockContext from "@reactioncommerce/api-utils/tests/mockContext.js";
import Khipu from "../../libkhipu/khipu.js";

import createAuthorizedPayment from "./reactionPaymentKhipuCreateAuthorizedPayment.js";

mockContext.khipuClient = new Khipu({
  basePath: "https://khipu.com/api/2.0",
  receiverID: "test",
  secret: "SECRET"
});

test("should call khipuClient.paymentsGet with the proper parameters and find the order object," +
    " modifying its status", async () => {
  const paymentData = {
    amount: 1234,
    billingAddress: "Av. Imaginaria, 123, Quilpué",
    currencyCode: "CLP",
    email: "matias.zuniga@sansano.usm.cl",
    shopId: "SHOP_ID",
    paymentData: {
      fullName: "Sr. Santa Claus",
      referenceId: "ORDER_REF_ID"
    }
  };

  const khipuPaymentPostResult = {
    payment_id: "KHIPU_PAYMENT_ID",
    payment_url: "https://fake.payment.khipu.com/pay/123456789ABCDE",
    app_url: "https://fake.payment.khipu.com/app/123456789ABCDE"
  };

  nock("https://khipu.com:443")
    .post("/api/2.0/payments", (body) => body.currency === "CLP" && body.amount === "1234" && body.transaction_id === "ORDER_REF_ID")
    .reply(200, khipuPaymentPostResult);

  const result = await createAuthorizedPayment(mockContext, paymentData);

  // should expire in a week
  const nowDate = new Date().getTime();
  const expireDate = new Date(result.data.expiresAfter).getTime();
  // a week from now
  expect(expireDate).toBeLessThanOrEqual(nowDate + (7 * 24 * 60 * 60000));
  // a week (minus a minute) from now
  expect(expireDate).toBeGreaterThan(nowDate + (7 * 24 * 60 * 60000) - 60000);

  expect(result.address).toBe("Av. Imaginaria, 123, Quilpué");
  expect(result.amount).toBe(1234);
  expect(result.currencyCode).toBe("CLP");
  expect(result.data.webURL).toBe("https://fake.payment.khipu.com/pay/123456789ABCDE");
  expect(result.data.appURL).toBe("https://fake.payment.khipu.com/app/123456789ABCDE");
  expect(result.mode).toBe("authorize");
  expect(result.processor).toBe("khipu");
  expect(result.shopId).toBe("SHOP_ID");
  expect(result.status).toBe("created");
  expect(result.transactionId).toBe("KHIPU_PAYMENT_ID");
  expect(result.transactions.length).toBe(0);
});
